import { MidwayError, registerErrorCode } from '@midwayjs/core';
/**自定义错误编码 */
export enum ErrorCode {
  /** 未知错误 */
  UNKNOWN = '-1',
  /** 缺少地址参数 */
  NEED_PARAMS = '-2',
  /** 错误地址参数 */
  BAD_PARAMS = '-20',
  /** 缺少地址后参数 */
  NEED_QUERY = '-3',
  /** 错误地址后参数 */
  BAD_QUERY = '-30',
  /** 缺少body参数 */
  NEED_BODY = '-4',
  /** 错误body参数 */
  BAD_BODY = '-40',
  /** 缺少参数(函数调用中) */
  NEED_ARGS = '-5',
  /** 错误参数 */
  BAD_ARGS = '-50',
  /** 未找到数据 */
  NOT_FOUND_DATA = '-10',
  /** 未找到数据,写错了,兼容下 */
  DATA_NOT_FOUND = '-10',
  /** 业务错误 */
  SERVICE_FAULT = '-100',
  /** 用户没有登录 */
  NOT_LOGIN = '-101',
  /** 密码错误 */
  BAD_PASSWORD = '-102',
  /**请求错误 */
  REQUEST_FAULT = '500',
}

/** 自定义错误枚举数据 */
export const FrameworkErrorEnum = registerErrorCode('ServiceError', ErrorCode);
/**
 * @constructor 自定义异常类
 * @param {string} str 异常说明
 * @param {ErrorCode} errcode 错误代码
 * @param {any} detail 错误细节
 */
export class ServiceError extends MidwayError {
  constructor(str: string, errcode: string = ErrorCode.UNKNOWN, detail?: any) {
    super(str, errcode);
    if (detail) {
      this.detail = detail;
    }
  }
  detail: any;
}
