import { getModelForClass, getClass } from '@typegoose/typegoose';
import { AnyParamConstructor } from '@typegoose/typegoose/lib/types';
import { FrameworkErrorEnum, ServiceError } from '../error/service.error';
import { upperFirst } from 'lodash';
/**
 * 根据表名返回model
 * @param modelName 表名
 * @returns model
 */
export function GetModel(modelName) {
  let model;
  try {
    model = getModelForClass(
      getClass(upperFirst(modelName)) as AnyParamConstructor<any>
    );
  } catch (error) {
    throw new ServiceError(`${modelName}-生成模型错误`, FrameworkErrorEnum.SERVICE_FAULT);
  }
  if (!model)
    throw new ServiceError(`${modelName}-未找到模型`, FrameworkErrorEnum.SERVICE_FAULT);

  return model;
}
